@@ -113,7 +113,7 @@ class UploadException(GlanceException):
 
 
 class Forbidden(GlanceException):
-    message = _("You are not authorized to complete this action.")
+    message = _("You are not authorized to complete %(action)s action.")
 
 
 class ForbiddenPublicImage(Forbidden):
@@ -397,7 +397,9 @@ class MetadefDuplicateResourceTypeAssociation(Duplicate):
 
 class MetadefDuplicateTag(Duplicate):
     message = _("A metadata tag with name=%(name)s"
-                " already exists in namespace=%(namespace_name)s.")
+                " already exists in namespace=%(namespace_name)s."
+                " (Please note that metadata tag names are"
+                " case insensitive).")
 
 
 class MetadefForbidden(Forbidden):
@@ -412,7 +414,7 @@ class MetadefIntegrityError(Forbidden):
 
 class MetadefNamespaceNotFound(NotFound):
     message = _("Metadata definition namespace=%(namespace_name)s"
-                "was not found.")
+                " was not found.")
 
 
 class MetadefObjectNotFound(NotFound):
@@ -445,10 +447,6 @@ class MetadefTagNotFound(NotFound):
                 " namespace=%(namespace_name)s.")
 
 
-class SignatureVerificationError(GlanceException):
-    message = _("Unable to verify signature: %(reason)s")
-
-
 class InvalidVersion(Invalid):
     message = _("Version is invalid: %(reason)s")
 
@@ -527,8 +525,8 @@ class ArtifactLoadError(GlanceException):
 
 
 class ArtifactNonMatchingTypeName(ArtifactLoadError):
-    message = _(
-        "Plugin name '%(plugin)s' should match artifact typename '%(name)s'")
+    message = _("Plugin name '%(plugin)s' should match "
+                "artifact typename '%(name)s'")
 
 
 class ArtifactPluginNotFound(NotFound):
